@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2009-2018  Brazil
-  Copyright (C) 2018-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2018-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -53,7 +53,7 @@ extern "C" {
 typedef struct _grn_alloc_info grn_alloc_info;
 struct _grn_alloc_info {
   void *address;
-  int freed;
+  bool freed;
   size_t size;
   char alloc_backtrace[4096];
   char free_backtrace[4096];
@@ -66,7 +66,7 @@ struct _grn_alloc_info {
 
 typedef struct _grn_mrb_data grn_mrb_data;
 struct _grn_mrb_data {
-  grn_bool initialized;
+  bool initialized;
 #ifdef GRN_WITH_MRUBY
   mrb_state *state;
   char base_directory[PATH_MAX];
@@ -89,7 +89,7 @@ struct _grn_mrb_data {
 
 typedef struct _grn_lua_data grn_lua_data;
 struct _grn_lua_data {
-  grn_bool initialized;
+  bool initialized;
 #ifdef GRN_WITH_LUAJIT
   lua_State *state;
 #endif
@@ -117,7 +117,7 @@ struct _grn_ctx_impl {
   grn_obj *curr_expr;
   grn_obj current_request_id;
   void *current_request_timer_id;
-  void *parser;
+  grn_obj expr_parsers;
   grn_timeval tv;
   grn_selector_data *current_selector_data;
 
@@ -141,7 +141,7 @@ struct _grn_ctx_impl {
     } data;
     grn_content_type type;
     const char *mime_type;
-    grn_bool is_pretty;
+    bool is_pretty;
     grn_obj names;
     grn_obj levels;
 #ifdef GRN_WITH_MESSAGE_PACK
@@ -150,12 +150,18 @@ struct _grn_ctx_impl {
     grn_arrow_stream_writer *arrow_stream_writer;
   } output;
 
+  struct {
+    int32_t n_workers;
+    void *task_executor;
+  } parallel;
+
   struct {
     int flags;
     grn_command_version version;
     struct {
       grn_obj *command;
       grn_command_version version;
+      int32_t n_workers;
     } keep;
   } command;
 
