@@ -1,6 +1,6 @@
 /*
-  Copyright(C) 2013-2016  Brazil
-  Copyright(C) 2020-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2013-2016  Brazil
+  Copyright (C) 2020-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -47,6 +47,11 @@ extern "C" {
     grn_gctx.rc = GRN_SUCCESS;                                                 \
   } while (0)
 
+void
+grn_error_init_from_env(void);
+void
+grn_error_cancel(grn_ctx *ctx);
+
 static grn_inline grn_rc
 grn_ctx_rc_propagate(grn_ctx *ctx, grn_rc rc)
 {
@@ -56,7 +61,7 @@ grn_ctx_rc_propagate(grn_ctx *ctx, grn_rc rc)
   return ctx->rc;
 }
 
-GRN_API grn_bool
+GRN_API bool
 grn_ctx_impl_should_log(grn_ctx *ctx);
 GRN_API void
 grn_ctx_impl_set_current_error_message(grn_ctx *ctx);
@@ -271,7 +276,7 @@ grn_error_set(grn_ctx *ctx,
     do {                                                                       \
       grn_rc rc;                                                               \
       int errno_keep = errno;                                                  \
-      grn_bool show_errno = GRN_FALSE;                                         \
+      bool show_errno = false;                                                 \
       const char *system_message;                                              \
       char user_message[USER_MESSAGE_SIZE];                                    \
       system_message = grn_strerror(errno);                                    \
@@ -376,7 +381,7 @@ grn_error_set(grn_ctx *ctx,
       /* case STRUNCATE : */                                                   \
       default:                                                                 \
         rc = GRN_UNKNOWN_ERROR;                                                \
-        show_errno = GRN_TRUE;                                                 \
+        show_errno = true;                                                     \
         break;                                                                 \
       }                                                                        \
       grn_snprintf(user_message,                                               \
@@ -400,7 +405,7 @@ grn_error_set(grn_ctx *ctx,
     do {                                                                       \
       grn_rc rc;                                                               \
       int errno_keep = errno;                                                  \
-      grn_bool show_errno = GRN_FALSE;                                         \
+      bool show_errno = false;                                                 \
       const char *system_message = grn_error_get_current_system_message();     \
       char user_message[USER_MESSAGE_SIZE];                                    \
       switch (errno_keep) {                                                    \
@@ -534,7 +539,7 @@ grn_error_set(grn_ctx *ctx,
         break;                                                                 \
       default:                                                                 \
         rc = GRN_UNKNOWN_ERROR;                                                \
-        show_errno = GRN_TRUE;                                                 \
+        show_errno = true;                                                     \
         break;                                                                 \
       }                                                                        \
       grn_snprintf(user_message,                                               \
