@@ -83,6 +83,8 @@ struct _grn_ii {
 
 #define GRN_II_PSEG_NOT_ASSIGNED 0xffffffff
 
+#define GRN_II_MAX_TF            0x1ffff
+
 #define GRN_II_HEADER_COMMON_FIELDS                                            \
   uint64_t total_chunk_size;                                                   \
   uint64_t bmax;                                                               \
@@ -191,8 +193,6 @@ grn_ii_max_section(grn_ii *ii);
 
 const char *
 grn_ii_path(grn_ii *ii);
-grn_obj *
-grn_ii_lexicon(grn_ii *ii);
 
 /*
 grn_rc grn_ii_upd(grn_ctx *ctx, grn_ii *ii, grn_id rid, grn_vgram *vgram,
@@ -228,6 +228,7 @@ struct _grn_select_optarg {
   grn_obj *query_options;
   grn_obj *max_element_intervals;
   int min_interval;
+  grn_id query_domain;
 };
 
 GRN_API grn_rc
