@@ -25,7 +25,8 @@
 extern "C" {
 #endif
 
-grn_io *grn_obj_get_io(grn_ctx *ctx, grn_obj *obj);
+grn_io *
+grn_obj_get_io(grn_ctx *ctx, grn_obj *obj);
 
 void
 grn_obj_set_error(grn_ctx *ctx,
@@ -45,7 +46,6 @@ grn_obj_log(grn_ctx *ctx,
             const char *format,
             ...);
 
-
 #ifdef __cplusplus
 }
 #endif
