@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2009-2018  Brazil
-  Copyright (C) 2019-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2019-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -32,8 +32,6 @@ void
 grn_proc_init_from_env(void);
 void
 grn_proc_query_init_from_env(void);
-void
-grn_proc_select_init_from_env(void);
 
 GRN_VAR const char *grn_document_root;
 void
@@ -64,6 +62,14 @@ grn_proc_init_config_delete(grn_ctx *ctx);
 void
 grn_proc_init_define_selector(grn_ctx *ctx);
 void
+grn_proc_init_distance_cosine(grn_ctx *ctx);
+void
+grn_proc_init_distance_inner_product(grn_ctx *ctx);
+void
+grn_proc_init_distance_l1_norm(grn_ctx *ctx);
+void
+grn_proc_init_distance_l2_norm_squared(grn_ctx *ctx);
+void
 grn_proc_init_dump(grn_ctx *ctx);
 void
 grn_proc_init_edit_distance(grn_ctx *ctx);
@@ -241,7 +247,7 @@ grn_proc_output_object_name(grn_ctx *ctx, grn_obj *obj);
 void
 grn_proc_output_object_id_name(grn_ctx *ctx, grn_id id);
 
-grn_bool
+bool
 grn_proc_table_set_token_filters(grn_ctx *ctx,
                                  grn_obj *table,
                                  grn_raw_string *token_filters_raw);
@@ -302,7 +308,7 @@ grn_proc_lexicon_open(grn_ctx *ctx,
                       grn_raw_string *token_filters_raw,
                       const char *context_tag);
 
-grn_bool
+bool
 grn_proc_text_include_special_character(grn_ctx *ctx,
                                         const char *text,
                                         size_t size);
