@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2013-2018  Brazil
-  Copyright (C) 2018-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2018-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -39,8 +39,8 @@ typedef struct {
   grn_obj *initial_result_set;
   grn_obj *result_set;
   grn_id min_id;
-  grn_bool is_first_unskipped_scan_info;
-  grn_bool is_skipped;
+  bool is_first_unskipped_scan_info;
+  bool is_skipped;
   grn_search_optarg search_options;
 } grn_table_selector_data;
 
@@ -54,6 +54,7 @@ struct _grn_table_selector {
   float weight_factor;
   double enough_filtered_ratio;
   int64_t max_n_enough_filtered_records;
+  bool ensure_using_select_result;
   grn_fuzzy_search_optarg fuzzy_options;
   grn_table_selector_data data;
 };
