@@ -25,11 +25,15 @@ extern "C" {
 
 extern grn_obj *grn_tokenizer_uvector;
 
-grn_rc grn_tokenizers_init(void);
-grn_rc grn_tokenizers_fin(void);
+grn_rc
+grn_tokenizers_init(void);
+grn_rc
+grn_tokenizers_fin(void);
 
-grn_rc grn_db_init_mecab_tokenizer(grn_ctx *ctx);
-grn_rc grn_db_init_builtin_tokenizers(grn_ctx *ctx);
+grn_rc
+grn_db_init_mecab_tokenizer(grn_ctx *ctx);
+grn_rc
+grn_db_init_builtin_tokenizers(grn_ctx *ctx);
 
 #ifdef __cplusplus
 }
