@@ -1,6 +1,6 @@
 /*
-  Copyright(C) 2018  Brazil
-  Copyright(C) 2018-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2018  Brazil
+  Copyright (C) 2018-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -191,6 +191,166 @@ grn_highlighter_close(grn_ctx *ctx, grn_highlighter *highlighter)
   GRN_API_RETURN(ctx->rc);
 }
 
+static void
+grn_highlighter_prepare_lexicon_add_token_id_chunks(
+  grn_ctx *ctx,
+  grn_highlighter *highlighter,
+  grn_token **tokens,
+  size_t n_tokens,
+  grn_obj *token_id_chunk)
+{
+  if (n_tokens == 0) {
+    if (GRN_TEXT_LEN(token_id_chunk) == 0) {
+      return;
+    }
+    grn_encoding encoding = ctx->encoding;
+    /* token_id_chunk is a binary data */
+    ctx->encoding = GRN_ENC_NONE;
+    grn_table_add(ctx,
+                  highlighter->lexicon.token_id_chunks,
+                  GRN_TEXT_VALUE(token_id_chunk),
+                  (unsigned int)GRN_TEXT_LEN(token_id_chunk),
+                  NULL);
+    ctx->encoding = encoding;
+  } else {
+    grn_token *token = tokens[0];
+    grn_obj *token_data = grn_token_get_data(ctx, token);
+    /* Expand immature token later. */
+    if (grn_token_get_force_prefix_search(ctx, token) &&
+        highlighter->lexicon.object->header.type != GRN_TABLE_HASH_KEY) {
+      grn_obj *lazy_keywords = &(highlighter->lexicon.lazy_keywords);
+      grn_vector_add_element(ctx,
+                             lazy_keywords,
+                             GRN_TEXT_VALUE(token_data),
+                             (uint32_t)GRN_TEXT_LEN(token_data),
+                             0,
+                             GRN_DB_TEXT);
+    }
+    grn_token_status token_status = grn_token_get_status(ctx, token);
+    if (token_status & GRN_TOKEN_UNMATURED &&
+        token_status & GRN_TOKEN_OVERLAP) {
+      /* This skips the current token.
+       *
+       * GRN_TOKENIZE_GET don't emit immature and overlapped token
+       * such as "c" in ["ab", "bc", "c"] for 'abc' with
+       * TokenNgram. But GRN_TOKENIZE_ONLY doesn't do it. So we do it
+       * manually here. */
+      grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                          highlighter,
+                                                          tokens + 1,
+                                                          n_tokens - 1,
+                                                          token_id_chunk);
+    } else {
+      grn_id token_id = GRN_ID_NIL;
+      /* We should not use grn_table_get() here. If we use
+       * grn_table_get(), token is normalized twice. */
+      switch (highlighter->lexicon.object->header.type) {
+      case GRN_TABLE_HASH_KEY:
+        token_id = grn_hash_get(ctx,
+                                (grn_hash *)(highlighter->lexicon.object),
+                                GRN_TEXT_VALUE(token_data),
+                                GRN_TEXT_LEN(token_data),
+                                NULL);
+        break;
+      case GRN_TABLE_PAT_KEY:
+        token_id = grn_pat_get(ctx,
+                               (grn_pat *)(highlighter->lexicon.object),
+                               GRN_TEXT_VALUE(token_data),
+                               GRN_TEXT_LEN(token_data),
+                               NULL);
+        break;
+      case GRN_TABLE_DAT_KEY:
+        token_id = grn_dat_get(ctx,
+                               (grn_dat *)(highlighter->lexicon.object),
+                               GRN_TEXT_VALUE(token_data),
+                               GRN_TEXT_LEN(token_data),
+                               NULL);
+        break;
+      }
+      /* GRN_TOKENIZE_ONLY may emit a token that doesn't exist in
+       * lexicon. */
+      if (token_id == GRN_ID_NIL) {
+        /* Lexicon: ["ab", "bc", "c"]
+         * Input: "abd"
+         * Tokens: ["ab", "bd", "d"]
+         *                ^
+         *                The current token
+         *
+         * Register the current token ID chunk (["ab"]), ignore "bd"
+         * and start a new token ID chunk ([]) with the next token
+         * ("d").
+         */
+
+        /* Register the current token ID chunk. */
+        grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                            highlighter,
+                                                            NULL,
+                                                            0,
+                                                            token_id_chunk);
+        /* Ignore the current token and start a new token ID chunk
+         * from here. */
+        GRN_BULK_REWIND(token_id_chunk);
+        grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                            highlighter,
+                                                            tokens + 1,
+                                                            n_tokens - 1,
+                                                            token_id_chunk);
+      } else {
+        /* This is for loose mode. In loose mode, we have two
+         * tokenized blocks that are separated by
+         * GRN_TOKENIER_END_MARK_UTF8 with GRN_TOKENIZE_ONLY.
+         *
+         * Example:
+         *   Tokenizer: TokenNgram("loose_blank", true)
+         *   Normalizer: NormalizerNFKC150
+         *   Input: "a b"
+         *   Tokens: ["a", "b", "U+FFF0", "ab"]
+         *                      ^
+         *                      GRN_TOKENIZER_END_MARK_UTF8
+         *
+         * If we found the separator, we split tokens with the
+         * separator and create two token ID chunks. */
+        if (GRN_TEXT_LEN(token_data) == GRN_TOKENIZER_END_MARK_UTF8_LEN &&
+            memcmp(GRN_TEXT_VALUE(token_data),
+                   GRN_TOKENIZER_END_MARK_UTF8,
+                   GRN_TOKENIZER_END_MARK_UTF8_LEN) == 0) {
+          /* Register the current token ID chunk. */
+          grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                              highlighter,
+                                                              NULL,
+                                                              0,
+                                                              token_id_chunk);
+          if (n_tokens > 1) {
+            /* If we have more tokens after we skip the
+             * GRN_TOKENIZER_END_MARK_UTF8 token, clear the current
+             * token ID chunk and start a new token ID chunk for
+             * tokens followed by the GRN_TOKENIZER_END_MARK_UTF8
+             * token. */
+            GRN_BULK_REWIND(token_id_chunk);
+            grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                                highlighter,
+                                                                tokens + 1,
+                                                                n_tokens - 1,
+                                                                token_id_chunk);
+          }
+        } else {
+          /* This is an existing token. We just add the current token
+           * to the current token ID chunk and continue collecting
+           * more tokens. */
+          GRN_RECORD_PUT(ctx, token_id_chunk, token_id);
+          grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                              highlighter,
+                                                              tokens + 1,
+                                                              n_tokens - 1,
+                                                              token_id_chunk);
+          grn_id used_token_id;
+          GRN_RECORD_POP(token_id_chunk, used_token_id);
+        }
+      }
+    }
+  }
+}
+
 static void
 grn_highlighter_prepare_lexicon(grn_ctx *ctx, grn_highlighter *highlighter)
 {
@@ -244,7 +404,6 @@ grn_highlighter_prepare_lexicon(grn_ctx *ctx, grn_highlighter *highlighter)
     const char *keyword;
     unsigned int keyword_length;
     grn_token_cursor *cursor;
-    grn_id token_id;
 
     keyword_length = grn_vector_get_element(ctx,
                                             &(highlighter->raw_keywords),
@@ -252,60 +411,53 @@ grn_highlighter_prepare_lexicon(grn_ctx *ctx, grn_highlighter *highlighter)
                                             &keyword,
                                             NULL,
                                             NULL);
-    cursor = grn_token_cursor_open(ctx,
-                                   highlighter->lexicon.object,
-                                   keyword,
-                                   keyword_length,
-                                   GRN_TOKENIZE_ADD,
-                                   0);
-    if (!cursor) {
-      continue;
-    }
-    while (grn_token_cursor_next(ctx, cursor) != GRN_ID_NIL) {
-    }
-    grn_token_cursor_close(ctx, cursor);
 
+    grn_obj tokens;
+    /* grn_token isn't grn_obj but we use GRN_PTR here for easy to implement...
+     */
+    GRN_PTR_INIT(&tokens, GRN_OBJ_VECTOR, GRN_ID_NIL);
     cursor = grn_token_cursor_open(ctx,
                                    highlighter->lexicon.object,
                                    keyword,
                                    keyword_length,
-                                   GRN_TOKENIZE_GET,
+                                   GRN_TOKENIZE_ONLY,
                                    0);
     if (!cursor) {
       continue;
     }
     GRN_BULK_REWIND(token_id_chunk);
-    while ((token_id = grn_token_cursor_next(ctx, cursor)) != GRN_ID_NIL) {
-      grn_token *token;
-      GRN_TEXT_PUT(ctx, token_id_chunk, &token_id, sizeof(grn_id));
-      token = grn_token_cursor_get_token(ctx, cursor);
-      if (grn_token_get_force_prefix_search(ctx, token) &&
-          highlighter->lexicon.object->header.type != GRN_TABLE_HASH_KEY) {
-        const char *data;
-        size_t data_length;
-
-        data = grn_token_get_data_raw(ctx, token, &data_length);
-        grn_vector_add_element(ctx,
-                               lazy_keywords,
-                               data,
-                               (uint32_t)data_length,
-                               0,
-                               GRN_DB_TEXT);
+    while (cursor->status != GRN_TOKEN_CURSOR_DONE) {
+      grn_token_cursor_next(ctx, cursor);
+      grn_token *token = grn_token_cursor_get_token(ctx, cursor);
+      /* This may be needless. */
+      grn_obj *token_data = grn_token_get_data(ctx, token);
+      if (GRN_TEXT_LEN(token_data) == 0) {
+        break;
       }
+      grn_token *copied_token = GRN_MALLOC(sizeof(grn_token));
+      grn_token_init_deep(ctx, copied_token);
+      grn_token_copy(ctx, copied_token, token);
+      GRN_PTR_PUT(ctx, &tokens, copied_token);
     }
     grn_token_cursor_close(ctx, cursor);
 
-    {
-      grn_encoding encoding = ctx->encoding;
-      /* token_id_chunk is a binary data */
-      ctx->encoding = GRN_ENC_NONE;
-      grn_table_add(ctx,
-                    highlighter->lexicon.token_id_chunks,
-                    GRN_TEXT_VALUE(token_id_chunk),
-                    (unsigned int)GRN_TEXT_LEN(token_id_chunk),
-                    NULL);
-      ctx->encoding = encoding;
+    size_t n_tokens = GRN_PTR_VECTOR_SIZE(&tokens);
+    if (n_tokens == 0) {
+      GRN_OBJ_FIN(ctx, &tokens);
+      continue;
     }
+    grn_token **raw_tokens = (grn_token **)GRN_BULK_HEAD(&tokens);
+    grn_highlighter_prepare_lexicon_add_token_id_chunks(ctx,
+                                                        highlighter,
+                                                        raw_tokens,
+                                                        n_tokens,
+                                                        token_id_chunk);
+    size_t i;
+    for (i = 0; i < n_tokens; i++) {
+      grn_token_fin(ctx, raw_tokens[i]);
+      GRN_FREE(raw_tokens[i]);
+    }
+    GRN_OBJ_FIN(ctx, &tokens);
   }
 }
 
@@ -413,18 +565,18 @@ grn_highlighter_prepare(grn_ctx *ctx, grn_highlighter *highlighter)
   highlighter->need_prepared = false;
 }
 
-static grn_bool
+static bool
 grn_ids_is_included(grn_id *ids, size_t n_ids, grn_id id)
 {
   size_t i;
 
   for (i = 0; i < n_ids; i++) {
     if (ids[i] == id) {
-      return GRN_TRUE;
+      return true;
     }
   }
 
-  return GRN_FALSE;
+  return false;
 }
 
 static void
@@ -562,29 +714,24 @@ grn_highlighter_highlight_lexicon_flush(grn_ctx *ctx,
 }
 
 static void
-grn_highlighter_highlight_lexicon(grn_ctx *ctx,
-                                  grn_highlighter *highlighter,
-                                  const char *text,
-                                  size_t text_length,
-                                  grn_obj *output)
+grn_highlighter_tokenize_lexicon(grn_ctx *ctx,
+                                 grn_highlighter *highlighter,
+                                 const char *text,
+                                 size_t text_length)
 {
   const char *tag = "[highlighter][highlight][lexicon]";
   grn_log_level log_level = GRN_LOG_DEBUG;
-  grn_token_cursor *cursor;
-  grn_obj *lazy_keyword_ids = &(highlighter->lexicon.lazy_keyword_ids);
   grn_obj *token_ids = &(highlighter->lexicon.token_ids);
   grn_obj *token_locations = &(highlighter->lexicon.token_locations);
-  grn_obj *candidates = &(highlighter->lexicon.candidates);
 
-  GRN_BULK_REWIND(lazy_keyword_ids);
   GRN_BULK_REWIND(token_ids);
   GRN_BULK_REWIND(token_locations);
-  cursor = grn_token_cursor_open(ctx,
-                                 highlighter->lexicon.object,
-                                 text,
-                                 text_length,
-                                 GRN_TOKENIZE_ADD,
-                                 0);
+  grn_token_cursor *cursor = grn_token_cursor_open(ctx,
+                                                   highlighter->lexicon.object,
+                                                   text,
+                                                   text_length,
+                                                   GRN_TOKENIZE_ADD,
+                                                   0);
   if (!cursor) {
     char errbuf[GRN_CTX_MSGSIZE];
     grn_strcpy(errbuf, GRN_CTX_MSGSIZE, ctx->errbuf);
@@ -618,6 +765,23 @@ grn_highlighter_highlight_lexicon(grn_ctx *ctx,
   }
   grn_token_cursor_close(ctx, cursor);
   GRN_LOG(ctx, log_level, "%s[tokenize][end]", tag);
+}
+
+static void
+grn_highlighter_highlight_lexicon(grn_ctx *ctx,
+                                  grn_highlighter *highlighter,
+                                  const char *text,
+                                  size_t text_length,
+                                  grn_obj *output)
+{
+  const char *tag = "[highlighter][highlight][lexicon]";
+  grn_log_level log_level = GRN_LOG_DEBUG;
+  grn_obj *lazy_keyword_ids = &(highlighter->lexicon.lazy_keyword_ids);
+  grn_obj *token_ids = &(highlighter->lexicon.token_ids);
+  grn_obj *token_locations = &(highlighter->lexicon.token_locations);
+  grn_obj *candidates = &(highlighter->lexicon.candidates);
+
+  GRN_BULK_REWIND(lazy_keyword_ids);
 
   {
     grn_obj *lexicon = highlighter->lexicon.object;
@@ -660,7 +824,7 @@ grn_highlighter_highlight_lexicon(grn_ctx *ctx,
           grn_table_add(ctx, chunks, &id, sizeof(grn_id), &added);
           ctx->encoding = encoding;
         }
-        if (grn_logger_pass(ctx, GRN_LOG_DEBUG)) {
+        if (grn_logger_pass(ctx, log_level)) {
           void *key;
           int key_size;
           key_size = grn_table_cursor_get_key(ctx, cursor, &key);
@@ -732,7 +896,6 @@ grn_highlighter_highlight_lexicon(grn_ctx *ctx,
       {
         grn_id *ids;
         uint32_t key_size;
-        size_t j;
         size_t n_ids;
         grn_highlighter_location candidate;
         grn_highlighter_location *first = raw_token_locations + i;
@@ -749,37 +912,17 @@ grn_highlighter_highlight_lexicon(grn_ctx *ctx,
         }
         n_ids = key_size / sizeof(grn_id);
         candidate.offset = first->offset;
-        if (n_ids == 1 && grn_ids_is_included(raw_lazy_keyword_ids,
-                                              n_lazy_keyword_ids,
-                                              ids[0])) {
-          candidate.length = first->first_character_length;
-        } else if (first->have_overlap && n_ids > 1) {
-          candidate.length = first->first_character_length;
+        if (n_ids == 1) {
+          if (grn_ids_is_included(raw_lazy_keyword_ids,
+                                  n_lazy_keyword_ids,
+                                  ids[0])) {
+            candidate.length = first->first_character_length;
+          } else {
+            candidate.length = first->length;
+          }
         } else {
-          candidate.length = first->length;
-        }
-        for (j = 1; j < n_ids; j++) {
-          grn_highlighter_location *current = raw_token_locations + i + j;
-          grn_highlighter_location *previous = current - 1;
-          uint32_t current_length;
-          uint32_t previous_length;
-          if (current->have_overlap && j + 1 < n_ids) {
-            current_length = current->first_character_length;
-          } else {
-            current_length = current->length;
-          }
-          if (previous->have_overlap && j + 1 < n_ids) {
-            previous_length = previous->first_character_length;
-          } else {
-            previous_length = previous->length;
-          }
-          if (current->offset == previous->offset) {
-            if (current_length > previous_length) {
-              candidate.length += current_length - previous_length;
-            }
-          } else {
-            candidate.length += current_length;
-          }
+          grn_highlighter_location *last = raw_token_locations + i + n_ids - 1;
+          candidate.length = last->offset + last->length - candidate.offset;
         }
         GRN_TEXT_PUT(ctx, candidates, &candidate, sizeof(candidate));
         grn_highlighter_log_location(ctx,
@@ -983,6 +1126,24 @@ grn_highlighter_highlight(grn_ctx *ctx,
     goto exit;
   }
 
+  if (highlighter->lexicon.object) {
+    /* We need to tokenize the target text with GRN_TOKENIZE_ADD
+     * before we call grn_highlighter_prepare_lexicon() because
+     * grn_highlighter_prepare_lexicon() assumes that the tokens of
+     * the target text exists in highlighter->lexicon.object.
+     *
+     * If we have any new tokens, we need to re-prepare. */
+    uint32_t size_before = grn_table_size(ctx, highlighter->lexicon.object);
+    grn_highlighter_tokenize_lexicon(ctx, highlighter, text, text_length);
+    if (ctx->rc != GRN_SUCCESS) {
+      goto exit;
+    }
+    uint32_t size_after = grn_table_size(ctx, highlighter->lexicon.object);
+    if (size_after > size_before) {
+      highlighter->need_prepared = true;
+    }
+  }
+
   if (highlighter->need_prepared) {
     grn_highlighter_prepare(ctx, highlighter);
     if (ctx->rc != GRN_SUCCESS) {
