@@ -1257,6 +1257,32 @@ exec_match_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *query)
   return matched;
 }
 
+static bool
+exec_prefix_vector_bulk(grn_ctx *ctx, grn_obj *vector, grn_obj *query)
+{
+  bool matched = false;
+
+  uint32_t size = grn_vector_size(ctx, vector);
+  grn_obj element;
+  GRN_VOID_INIT(&element);
+
+  for (uint32_t i = 0; i < size; i++) {
+    const char *content;
+    grn_id domain_id;
+    uint32_t content_size =
+      grn_vector_get_element(ctx, vector, i, &content, NULL, &domain_id);
+    grn_obj_reinit(ctx, &element, domain_id, 0);
+    grn_bulk_write(ctx, &element, content, content_size);
+    if (grn_operator_exec_prefix(ctx, &element, query)) {
+      matched = true;
+      break;
+    }
+  }
+  GRN_OBJ_FIN(ctx, &element);
+
+  return matched;
+}
+
 #ifdef GRN_SUPPORT_REGEXP
 static grn_bool
 regexp_is_match(grn_ctx *ctx,
@@ -1561,12 +1587,27 @@ grn_operator_exec_match(grn_ctx *ctx, grn_obj *target, grn_obj *sub_text)
   GRN_API_RETURN(matched);
 }
 
-grn_bool
+bool
 grn_operator_exec_prefix(grn_ctx *ctx, grn_obj *target, grn_obj *prefix)
 {
-  grn_bool matched;
+  bool matched;
   GRN_API_ENTER;
-  matched = exec_text_operator_bulk_bulk(ctx, GRN_OP_PREFIX, target, prefix);
+  switch (target->header.type) {
+  case GRN_UVECTOR:
+    // Probably, we can't search of prefix against UVECTOR.
+    matched = false;
+    break;
+  case GRN_VECTOR:
+    matched = exec_prefix_vector_bulk(ctx, target, prefix);
+    break;
+  case GRN_BULK:
+    matched = exec_text_operator_bulk_bulk(ctx, GRN_OP_PREFIX, target, prefix);
+    break;
+  default:
+    matched = false;
+    break;
+  }
+
   GRN_API_RETURN(matched);
 }
 
