@@ -17,6 +17,7 @@
 */
 
 #include "grn.h"
+#include "grn_applier.h"
 #include "grn_ctx.h"
 #include "grn_ctx_impl.h"
 #include "grn_expr_executor.h"
@@ -27,8 +28,6 @@ grn_table_apply_expr(grn_ctx *ctx,
                      grn_obj *output_column,
                      grn_obj *expr)
 {
-  grn_expr_executor executor;
-
   GRN_API_ENTER;
 
   if (!grn_obj_is_data_column(ctx, output_column)) {
@@ -55,44 +54,48 @@ grn_table_apply_expr(grn_ctx *ctx,
     GRN_API_RETURN(ctx->rc);
   }
 
-  grn_expr_executor_init(ctx, &executor, expr);
-  if (ctx->rc != GRN_SUCCESS) {
+  grn_applier_data data = {0};
+  grn_applier_data_init(ctx, &data, table, output_column);
+  if (grn_applier_data_extract(ctx, &data, expr)) {
+    grn_rc rc = grn_applier_data_run(ctx, &data);
+    grn_applier_data_fin(ctx, &data);
+    GRN_API_RETURN(rc);
+  } else {
+    grn_applier_data_fin(ctx, &data);
+
+    grn_expr_executor executor;
+    grn_expr_executor_init(ctx, &executor, expr);
+    if (ctx->rc != GRN_SUCCESS) {
+      GRN_API_RETURN(ctx->rc);
+    }
+    GRN_TABLE_EACH_BEGIN_FLAGS(ctx, table, cursor, id, GRN_CURSOR_BY_ID)
+    {
+      grn_obj *value;
+      value = grn_expr_executor_exec(ctx, &executor, id);
+      if (ctx->rc != GRN_SUCCESS) {
+        break;
+      }
+      if (value) {
+        grn_obj_set_value(ctx, output_column, id, value, GRN_OBJ_SET);
+      }
+      if (ctx->rc != GRN_SUCCESS) {
+        break;
+      }
+    }
+    GRN_TABLE_EACH_END(ctx, cursor);
+    grn_expr_executor_fin(ctx, &executor);
+
     GRN_API_RETURN(ctx->rc);
   }
-  GRN_TABLE_EACH_BEGIN_FLAGS(ctx, table, cursor, id, GRN_CURSOR_BY_ID)
-  {
-    grn_obj *value;
-    value = grn_expr_executor_exec(ctx, &executor, id);
-    if (ctx->rc != GRN_SUCCESS) {
-      break;
-    }
-    if (value) {
-      grn_obj_set_value(ctx, output_column, id, value, GRN_OBJ_SET);
-    }
-    if (ctx->rc != GRN_SUCCESS) {
-      break;
-    }
-  }
-  GRN_TABLE_EACH_END(ctx, cursor);
-  grn_expr_executor_fin(ctx, &executor);
-
-  GRN_API_RETURN(ctx->rc);
 }
 
 grn_id
-grn_table_find_reference_object(grn_ctx *ctx, grn_obj *table)
+grn_table_find_reference_object_raw(grn_ctx *ctx, grn_id table_id)
 {
-  grn_id table_id;
   grn_id reference_object_id = GRN_ID_NIL;
 
   GRN_API_ENTER;
 
-  if (!grn_obj_is_table(ctx, table)) {
-    GRN_API_RETURN(GRN_ID_NIL);
-  }
-
-  table_id = DB_OBJ(table)->id;
-
   GRN_DB_EACH_SPEC_BEGIN(ctx, cursor, id, spec)
   {
     if (id == table_id) {
@@ -129,6 +132,22 @@ grn_table_find_reference_object(grn_ctx *ctx, grn_obj *table)
   GRN_API_RETURN(reference_object_id);
 }
 
+grn_id
+grn_table_find_reference_object(grn_ctx *ctx, grn_obj *table)
+{
+  GRN_API_ENTER;
+
+  if (!grn_obj_is_table(ctx, table)) {
+    GRN_API_RETURN(GRN_ID_NIL);
+  }
+
+  grn_id table_id = DB_OBJ(table)->id;
+  grn_id reference_object_id =
+    grn_table_find_reference_object_raw(ctx, table_id);
+
+  GRN_API_RETURN(reference_object_id);
+}
+
 static void
 grn_table_copy_array(grn_ctx *ctx, grn_obj *from, grn_obj *to)
 {
