@@ -116,6 +116,7 @@ grn_table_selector_init(grn_ctx *ctx,
     grn_table_select_enough_filtered_ratio;
   table_selector->max_n_enough_filtered_records =
     grn_table_select_max_n_enough_filtered_records;
+  table_selector->ensure_using_select_result = false;
   grn_fuzzy_search_optarg fuzzy_options = {0};
   table_selector->fuzzy_options = fuzzy_options;
   table_selector->fuzzy_options.flags |=
@@ -244,6 +245,22 @@ grn_table_selector_set_max_n_enough_filtered_records(
   GRN_API_RETURN(ctx->rc);
 }
 
+bool
+grn_table_selector_get_ensure_using_select_result(
+  grn_ctx *ctx, grn_table_selector *table_selector)
+{
+  return table_selector->ensure_using_select_result;
+}
+
+grn_rc
+grn_table_selector_set_ensure_using_select_result(
+  grn_ctx *ctx, grn_table_selector *table_selector, bool use)
+{
+  GRN_API_ENTER;
+  table_selector->ensure_using_select_result = use;
+  GRN_API_RETURN(ctx->rc);
+}
+
 uint32_t
 grn_table_selector_get_fuzzy_max_distance(grn_ctx *ctx,
                                           grn_table_selector *table_selector)
@@ -1047,37 +1064,59 @@ select_index_fix(grn_ctx *ctx,
     grn_obj dest;
     GRN_OBJ_INIT(&dest, GRN_BULK, 0, table->header.domain);
     if (!grn_obj_cast(ctx, si->query, &dest, false)) {
-      grn_hash *pres;
-      if ((pres = grn_hash_create(ctx,
-                                  NULL,
-                                  sizeof(grn_id),
-                                  0,
-                                  GRN_OBJ_TABLE_HASH_KEY))) {
-        grn_table_search(ctx,
-                         index,
-                         GRN_BULK_HEAD(&dest),
-                         (uint32_t)GRN_BULK_VSIZE(&dest),
-                         op,
-                         (grn_obj *)pres,
-                         GRN_OP_OR);
-        grn_posting_internal posting = {0};
-        posting.sid = 1;
-        posting.pos = 0;
-        posting.weight_float = 1;
-        GRN_HASH_EACH_BEGIN(ctx, pres, cursor, id)
-        {
-          void *key;
-          grn_hash_cursor_get_key(ctx, cursor, &key);
-          posting.rid = *((grn_id *)key);
-          grn_ii_posting_add_float(ctx,
-                                   (grn_posting *)(&posting),
-                                   (grn_hash *)result_set,
-                                   logical_op);
+      if (op == GRN_OP_PREFIX) {
+        grn_table_cursor *cursor =
+          grn_table_cursor_open(ctx,
+                                index,
+                                GRN_BULK_HEAD(&dest),
+                                (uint32_t)GRN_BULK_VSIZE(&dest),
+                                NULL,
+                                0,
+                                0,
+                                -1,
+                                GRN_CURSOR_PREFIX | GRN_CURSOR_GE);
+        if (cursor) {
+          rc = grn_result_set_add_table_cursor(ctx,
+                                               (grn_hash *)result_set,
+                                               cursor,
+                                               1.0,
+                                               logical_op);
+          grn_table_cursor_close(ctx, cursor);
+        }
+      } else {
+        grn_hash *pres;
+        if ((pres = grn_hash_create(ctx,
+                                    NULL,
+                                    sizeof(grn_id),
+                                    0,
+                                    GRN_OBJ_TABLE_HASH_KEY))) {
+          rc = grn_table_search(ctx,
+                                index,
+                                GRN_BULK_HEAD(&dest),
+                                (uint32_t)GRN_BULK_VSIZE(&dest),
+                                op,
+                                (grn_obj *)pres,
+                                GRN_OP_OR);
+          if (rc == GRN_SUCCESS) {
+            grn_posting_internal posting = {0};
+            posting.sid = 1;
+            posting.pos = 0;
+            posting.weight_float = 1;
+            GRN_HASH_EACH_BEGIN(ctx, pres, cursor, id)
+            {
+              void *key;
+              grn_hash_cursor_get_key(ctx, cursor, &key);
+              posting.rid = *((grn_id *)key);
+              grn_ii_posting_add_float(ctx,
+                                       (grn_posting *)(&posting),
+                                       (grn_hash *)result_set,
+                                       logical_op);
+            }
+            GRN_HASH_EACH_END(ctx, cursor);
+            grn_hash_close(ctx, pres);
+          }
         }
-        GRN_HASH_EACH_END(ctx, cursor);
-        grn_hash_close(ctx, pres);
       }
-      rc = GRN_SUCCESS;
       grn_ii_resolve_sel_and(ctx, (grn_hash *)result_set, logical_op);
     }
     GRN_OBJ_FIN(ctx, &dest);
@@ -1235,16 +1274,29 @@ select_index_call(grn_ctx *ctx,
       table = grn_ctx_at(ctx, range);
       table_is_referred = true;
     }
-    rc = grn_selector_run(ctx,
-                          selector,
-                          data->expr,
-                          table,
-                          index_datum.index,
-                          (size_t)(si->nargs),
-                          si->args,
-                          si->weight_factor,
-                          result_set,
-                          logical_op);
+    grn_selector_data selector_data;
+    grn_selector_data_init(ctx,
+                           &selector_data,
+                           selector,
+                           data->expr,
+                           table,
+                           index_datum.index,
+                           (size_t)(si->nargs),
+                           si->args,
+                           si->weight_factor,
+                           result_set,
+                           logical_op);
+    bool can_swap_result_set = table_selector->ensure_using_select_result;
+    if (can_swap_result_set) {
+      grn_selector_data_set_can_swap_result_set(ctx, &selector_data, true);
+    }
+    rc = grn_selector_run(ctx, &selector_data);
+    if (rc == GRN_SUCCESS && can_swap_result_set &&
+        result_set != selector_data.result_set) {
+      grn_obj_unref(ctx, result_set);
+      table_selector->data.result_set = selector_data.result_set;
+    }
+    grn_selector_data_fin(ctx, &selector_data);
     if (table_is_referred) {
       grn_obj_unref(ctx, table);
     }
@@ -1850,16 +1902,32 @@ select_index(grn_ctx *ctx, grn_table_selector *table_selector)
                        proc_name);
           select_index_report(ctx, tag, table_selector->table);
         }
-        rc = grn_selector_run(ctx,
-                              selector,
-                              data->expr,
-                              table_selector->table,
-                              NULL,
-                              (size_t)(si->nargs),
-                              si->args,
-                              si->weight_factor,
-                              data->result_set,
-                              si->logical_op);
+        grn_selector_data selector_data;
+        grn_selector_data_init(ctx,
+                               &selector_data,
+                               selector,
+                               data->expr,
+                               table_selector->table,
+                               NULL,
+                               (size_t)(si->nargs),
+                               si->args,
+                               si->weight_factor,
+                               data->result_set,
+                               si->logical_op);
+        bool can_swap_result_set = table_selector->ensure_using_select_result;
+        if (can_swap_result_set) {
+          grn_selector_data_set_can_swap_result_set(ctx, &selector_data, true);
+        }
+        rc = grn_selector_run(ctx, &selector_data);
+        if (rc == GRN_SUCCESS && can_swap_result_set &&
+            data->result_set != selector_data.result_set) {
+          grn_obj *result_set = data->result_set;
+          data->result_set = selector_data.result_set;
+          if (result_set != data->initial_result_set) {
+            grn_obj_close(ctx, result_set);
+          }
+        }
+        grn_selector_data_fin(ctx, &selector_data);
       }
     }
   }
@@ -2131,7 +2199,24 @@ grn_table_selector_select(grn_ctx *ctx,
   data->variable = grn_expr_get_var_by_offset(ctx, data->expr, 0);
   data->is_skipped = false;
   data->is_first_unskipped_scan_info = true;
-  if (result_set_size > 0 && table_selector->op == GRN_OP_AND) {
+
+  /* This is an optimization for the following cases:
+   *
+   *   XXX && sub_filter(..., "YYY || ZZZ")
+   *   XXX && query(..., "YYY OR ZZZ")
+   *
+   * In these cases, sub_filter()/query() use
+   * grn_table_selector_select() with GRN_OP_OR and result_set with
+   * some records. If we use a copy of result_set as a base result set
+   * and GRN_OP_AND internally, we can reduce set operation cost.
+   *
+   * But if result_set has many records, this optimization will be
+   * slower than the normal operation. So we don't use this
+   * optimization if result_set already has many records. 1_000_000 is
+   * a heuristic value. This may not be a good value.
+   */
+  if (result_set_size > 0 && result_set_size < 1000000 &&
+      table_selector->op == GRN_OP_AND) {
     bool have_push = false;
     uint32_t i;
     for (i = 0; i < data->scanner->n_sis; i++) {
@@ -2175,14 +2260,47 @@ grn_table_selector_select(grn_ctx *ctx,
       if (si->flags & SCAN_POP) {
         grn_obj *result_set_;
         GRN_PTR_POP(&result_set_stack, result_set_);
+        grn_obj *table1 = result_set_;
+        grn_obj *table2 = data->result_set;
+        /* This is an optimization. In general, we do "result_set_ AND
+         * data->result_set" and update result_set_ in-place. This may
+         * be a heavy process when result_set_ is very large and
+         * data->result_set is small. Because we need to remove many
+         * records from result_set_. If we do "data->result_set AND
+         * result_set_" and update data->result_set, it's faster than
+         * before. Because we don't need to remove many records.
+         *
+         * We can't do this optimization when result_set_ is the given
+         * result_set to keep backward compatibility. Callers must use
+         * grn_table_selector_select()'s return value instead of the
+         * given result_set as the result but some callers may not do
+         * it. So this optimization is enabled only when
+         * grn_table_selector_set_ensure_using_select_result(ctx,
+         * table_selector, true) is called. (Or result_set_ isn't the
+         * given result_set.)
+         *
+         * This optimization will work for GRN_OP_OR but we target
+         * only GRN_OP_AND for now. We'll add support for GRN_OP_OR
+         * when we have an use case. */
+        if ((table_selector->ensure_using_select_result ||
+             table1 != result_set) &&
+            si->logical_op == GRN_OP_AND) {
+          if (grn_table_size(ctx, table1) > grn_table_size(ctx, table2)) {
+            grn_obj *tmp = table1;
+            table1 = table2;
+            table2 = tmp;
+          }
+        }
         grn_table_setoperation_with_weight_factor(ctx,
-                                                  result_set_,
-                                                  data->result_set,
-                                                  result_set_,
+                                                  table1,
+                                                  table2,
+                                                  table1,
                                                   si->logical_op,
                                                   si->weight_factor);
-        grn_obj_close(ctx, data->result_set);
-        data->result_set = result_set_;
+        if (table2 != result_set) {
+          grn_obj_close(ctx, table2);
+        }
+        data->result_set = table1;
         data->min_id = table_selector->min_id;
       } else {
         bool processed = false;
