@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2010-2018  Brazil
-  Copyright (C) 2019-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2019-2024  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -17,12 +17,13 @@
 */
 
 #include "grn_db.h"
-#include "grn_pat.h"
-#include "grn_ii.h"
-#include "grn_util.h"
-#include "grn_string.h"
 #include "grn_expr.h"
+#include "grn_float.h"
+#include "grn_ii.h"
 #include "grn_load.h"
+#include "grn_pat.h"
+#include "grn_string.h"
+#include "grn_util.h"
 
 #include <string.h>
 #include <stdio.h>
@@ -211,7 +212,7 @@ grn_inspect_type(grn_ctx *ctx, grn_obj *buf, unsigned char type)
 grn_obj *
 grn_inspect_query_log_flags(grn_ctx *ctx, grn_obj *buffer, unsigned int flags)
 {
-  grn_bool have_content = GRN_FALSE;
+  bool have_content = false;
 
   if (flags == GRN_QUERY_LOG_NONE) {
     GRN_TEXT_PUTS(ctx, buffer, "NONE");
@@ -225,9 +226,9 @@ grn_inspect_query_log_flags(grn_ctx *ctx, grn_obj *buffer, unsigned int flags)
         GRN_TEXT_PUTS(ctx, buffer, "|");                                       \
       }                                                                        \
       GRN_TEXT_PUTS(ctx, buffer, #NAME);                                       \
-      have_content = GRN_TRUE;                                                 \
+      have_content = true;                                                     \
     }                                                                          \
-  } while (GRN_FALSE)
+  } while (false)
 
   CHECK_FLAG(COMMAND);
   CHECK_FLAG(RESULT_CODE);
@@ -431,6 +432,15 @@ grn_vector_inspect(grn_ctx *ctx, grn_obj *buffer, grn_obj *vector)
   uint32_t i;
   grn_obj *body = vector->u.v.body;
 
+  bool have_weight = false;
+  for (i = 0; i < vector->u.v.n_sections; i++) {
+    grn_section *section = &(vector->u.v.sections[i]);
+    if (!grn_float32_is_zero(section->weight)) {
+      have_weight = true;
+      break;
+    }
+  }
+
   GRN_TEXT_PUTS(ctx, buffer, "[");
   for (i = 0; i < vector->u.v.n_sections; i++) {
     grn_section *section = &(vector->u.v.sections[i]);
@@ -441,8 +451,10 @@ grn_vector_inspect(grn_ctx *ctx, grn_obj *buffer, grn_obj *vector)
     }
 
     value_raw = GRN_BULK_HEAD(body) + section->offset;
-    GRN_TEXT_PUTS(ctx, buffer, "{");
-    GRN_TEXT_PUTS(ctx, buffer, "\"value\":");
+    if (have_weight) {
+      GRN_TEXT_PUTS(ctx, buffer, "{");
+      GRN_TEXT_PUTS(ctx, buffer, "\"value\":");
+    }
     {
       grn_obj value_object;
       GRN_OBJ_INIT(&value_object,
@@ -453,9 +465,11 @@ grn_vector_inspect(grn_ctx *ctx, grn_obj *buffer, grn_obj *vector)
       grn_inspect(ctx, buffer, &value_object);
       GRN_OBJ_FIN(ctx, &value_object);
     }
-    GRN_TEXT_PUTS(ctx, buffer, ", \"weight\":");
-    grn_text_f32toa(ctx, buffer, section->weight);
-    GRN_TEXT_PUTS(ctx, buffer, "}");
+    if (have_weight) {
+      GRN_TEXT_PUTS(ctx, buffer, ", \"weight\":");
+      grn_text_f32toa(ctx, buffer, section->weight);
+      GRN_TEXT_PUTS(ctx, buffer, "}");
+    }
   }
   GRN_TEXT_PUTS(ctx, buffer, "]");
 
@@ -1260,7 +1274,7 @@ static grn_rc
 grn_record_inspect_common(grn_ctx *ctx,
                           grn_obj *buf,
                           grn_obj *obj,
-                          grn_bool with_columns)
+                          bool with_columns)
 {
   grn_obj *table;
 
@@ -1351,20 +1365,20 @@ grn_record_inspect_common(grn_ctx *ctx,
 grn_rc
 grn_record_inspect_without_columns(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
 {
-  return grn_record_inspect_common(ctx, buf, obj, GRN_FALSE);
+  return grn_record_inspect_common(ctx, buf, obj, false);
 }
 
 static grn_rc
 grn_record_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
 {
-  return grn_record_inspect_common(ctx, buf, obj, GRN_TRUE);
+  return grn_record_inspect_common(ctx, buf, obj, true);
 }
 
 static grn_rc
 grn_uvector_record_inspect_common(grn_ctx *ctx,
                                   grn_obj *buf,
                                   grn_obj *obj,
-                                  grn_bool with_columns)
+                                  bool with_columns)
 {
   unsigned int i, n = 0;
   grn_obj record;
@@ -1397,13 +1411,13 @@ grn_uvector_record_inspect_without_columns(grn_ctx *ctx,
                                            grn_obj *buf,
                                            grn_obj *obj)
 {
-  return grn_uvector_record_inspect_common(ctx, buf, obj, GRN_FALSE);
+  return grn_uvector_record_inspect_common(ctx, buf, obj, false);
 }
 
 static grn_rc
 grn_uvector_record_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
 {
-  return grn_uvector_record_inspect_common(ctx, buf, obj, GRN_TRUE);
+  return grn_uvector_record_inspect_common(ctx, buf, obj, true);
 }
 
 grn_obj *
@@ -1735,7 +1749,7 @@ grn_mkstemp(char *path_template)
 }
 #endif   /* WIN32 */
 
-grn_bool
+bool
 grn_path_exist(const char *path)
 {
   struct stat status;
